"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useAnimatedPresence;
var _framerMotion = require("framer-motion");
var _react = require("react");
var _reactNative = require("react-native");
const {
  timing
} = _reactNative.Animated;
const defaultConfig = {
  duration: 300
};
function useAnimatedPresence() {
  let timingConfig = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultConfig;
  const animatedIsPresent = (0, _react.useRef)(new _reactNative.Animated.Value(0)).current;
  const [isPresent, safeToRemove] = (0, _framerMotion.usePresence)();
  (0, _react.useEffect)(() => {
    timing(animatedIsPresent, {
      toValue: isPresent ? 1 : 0,
      duration: timingConfig.duration,
      useNativeDriver: true
    }).start(_ref => {
      let {
        finished
      } = _ref;
      if (finished && !isPresent && safeToRemove) {
        safeToRemove();
      }
    });
  }, [animatedIsPresent, isPresent, safeToRemove, timingConfig.duration]);
  return animatedIsPresent;
}
//# sourceMappingURL=useAnimatedPresence.js.map