import { usePresence } from 'framer-motion';
import { useEffect, useRef } from 'react';
import { Animated } from 'react-native';
const {
  timing
} = Animated;
const defaultConfig = {
  duration: 300
};
export default function useAnimatedPresence() {
  let timingConfig = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : defaultConfig;
  const animatedIsPresent = useRef(new Animated.Value(0)).current;
  const [isPresent, safeToRemove] = usePresence();
  useEffect(() => {
    timing(animatedIsPresent, {
      toValue: isPresent ? 1 : 0,
      duration: timingConfig.duration,
      useNativeDriver: true
    }).start(_ref => {
      let {
        finished
      } = _ref;
      if (finished && !isPresent && safeToRemove) {
        safeToRemove();
      }
    });
  }, [animatedIsPresent, isPresent, safeToRemove, timingConfig.duration]);
  return animatedIsPresent;
}
//# sourceMappingURL=useAnimatedPresence.js.map