import { usePresence } from 'framer-motion';
import { runOnJS, useDerivedValue, withSequence, withTiming } from 'react-native-reanimated';
export default function useReanimated2Presence() {
  let timingConfig = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
    duration: 50
  };
  const [isPresent, safeToRemove] = usePresence();
  const animatedIsPresent = useDerivedValue(() => {
    if (isPresent) {
      return withSequence(withTiming(0, {
        duration: 0
      }), withTiming(1, timingConfig));
    } else {
      return withTiming(0, timingConfig, () => {
        if (safeToRemove) {
          runOnJS(safeToRemove)();
        }
      });
    }
  }, [isPresent]);
  return animatedIsPresent;
}
//# sourceMappingURL=useReanimated2Presence.js.map